@@ -30,9 +30,9 @@ def generate_cert(domain, cert_dir="certs"):
                     "-key",
                     private_key,
                     "-subj",
-                    '"/"',
+                    "/",
                     "-addext",
-                    f'"subjectAltName = DNS:{domain}, DNS:www.{domain}"',
+                    f"subjectAltName = DNS:{domain}, DNS:www.{domain}",
                 ],
                 stdout=fp,
             )
